# Pupil tracker

Track pupil diameter changes semi-automatically by using ROIs, brightness thresholding, color clustering, and/or ROIs.


## Installation
* Install [Python version 3.8][Python38]
* Open command prompt
* Run `pip install pupillometry` or `python -m pip install pupillometry`


## Usage overview
* Open `cmd`
* Run `python -m pupillometry.pupil --annotate "C:\Users\Molina\Documents\public\data\pupil\amph01_vid_15fps.mp4"`
* Annotate using mouse and shortcuts:
	- TBD
* Export results:
	- TBD


## Version History
* 0.0.1: Initial release.

## License
© 2019 [Leonardo Molina][Leonardo Molina]

This project is licensed under the [GNU GPLv3 License][LICENSE.md].

[Leonardo Molina]: https://github.com/leomol
[LICENSE.md]: LICENSE.md

[Python38]: https://www.python.org/downloads/